﻿using System;
using System.Linq;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace CSHowDoISamples
{
    public partial class LegendForm : Form
    {
        public LegendForm()
        {
            InitializeComponent();
            this.Load += this.Form_Load;
        }
        private void Form_Load(object sender, EventArgs e)
        {
            //mapView.MapTools.PanZoomBar.IsEnabled = false;
            this.WindowState = FormWindowState.Maximized;
            mapView.MapUnit = GeographyUnit.Meter;

            var housingUnitsLayer = new ShapeFileFeatureLayer(@"./Data/Frisco 2010 Census Housing Units.shp");
            var legend = new LegendAdornmentLayer
            {
                Height = 900,
                Title = new LegendItem()
                {
                    TextStyle = new TextStyle("Housing Units", new GeoFont("Verdana", 10, DrawingFontStyles.Bold), GeoBrushes.Black)
                },
                Location = AdornmentLocation.LowerRight
            };

            mapView.AdornmentOverlay.Layers.Add(legend);

            housingUnitsLayer.FeatureSource.Projection = new Proj4Projection(2276, 3857);
                //ProjectionConverter = new ProjectionConverter(2276, 3857);

            AddClassBreakStyle(housingUnitsLayer, legend);

            var layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(housingUnitsLayer);

            mapView.Overlays.Add(layerOverlay);

            housingUnitsLayer.Open();
            mapView.CurrentExtent = housingUnitsLayer.GetBoundingBox();
            housingUnitsLayer.Close();

            mapView.Refresh();

        }

        private void AddClassBreakStyle(ShapeFileFeatureLayer layer, LegendAdornmentLayer legend)
        {
            var housingUnitsStyle = new ClassBreakStyle("H_UNITS");

            var classBreakIntervals = new double[] { 0, 100, 200, 300, 400, 500, 600, 700, 800, 900, 1000, 1100, 1200, 1300, 1400, 1500,
                1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000,
                3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000 };

            var colors = GeoColor.GetColorsInHueFamily(GeoColors.Red, classBreakIntervals.Count()).Reverse().ToList();

            for (int i = 0; i < classBreakIntervals.Count(); i++)
            {
                var classBreak = new ClassBreak(classBreakIntervals[i], AreaStyles.CreateSimpleAreaStyle(new GeoColor(192, colors[i]), GeoColors.White));

                housingUnitsStyle.ClassBreaks.Add(classBreak);

                var legendItem = new LegendItem()
                {
                    ImageStyle = classBreak.DefaultAreaStyle,
                    ImageWidth = 60,
                    ImageHeight = 8,
                    TextStyle = new TextStyle($@">{classBreak.Value} units", new GeoFont("Verdana", 10), GeoBrushes.Black)
                };
                legend.LegendItems.Add(legendItem);
            }

            layer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(housingUnitsStyle);
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        }
    }
}